AssetSourceEntry class

The source of the assets.

Constructors

AssetSourceEntry({required String bucket, required String key})
AssetSourceEntry.fromJson(Map<String, dynamic> json)
factory

Properties

bucket → String
The S3 bucket that's part of the source of the asset.
final
hashCode → int
The hash code for this object.
no setterinherited
key → String
The name of the object in Amazon S3 for the asset.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited