DataSetEntry class

A data set is an AWS resource with one or more revisions.

Constructors

DataSetEntry({required String arn, required AssetType assetType, required DateTime createdAt, required String description, required String id, required String name, required Origin origin, required DateTime updatedAt, OriginDetails? originDetails, String? sourceId})
DataSetEntry.fromJson(Map<String, dynamic> json)
factory

Properties

arn → String
The ARN for the data set.
final
assetType → AssetType
The type of file your data is stored in. Currently, the supported asset type is S3_SNAPSHOT.
final
createdAt → DateTime
The date and time that the data set was created, in ISO 8601 format.
final
description → String
The description for the data set.
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
The unique identifier for the data set.
final
name → String
The name of the data set.
final
origin → Origin
A property that defines the data set as OWNED by the account (for providers) or ENTITLED to the account (for subscribers).
final
originDetails → OriginDetails?
If the origin of this data set is ENTITLED, includes the details for the product on AWS Marketplace.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceId → String?
The data set ID of the owned data set corresponding to the entitled data set being viewed. This parameter is returned when a data set owner is viewing the entitled copy of its owned data set.
final
updatedAt → DateTime
The date and time that the data set was last updated, in ISO 8601 format.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited