ExportAssetToSignedUrlResponseDetails class

The details of the export to signed URL response.

Constructors

ExportAssetToSignedUrlResponseDetails({required String assetId, required String dataSetId, required String revisionId, String? signedUrl, DateTime? signedUrlExpiresAt})
ExportAssetToSignedUrlResponseDetails.fromJson(Map<String, dynamic> json)
factory

Properties

assetId → String
The unique identifier for the asset associated with this export job.
final
dataSetId → String
The unique identifier for the data set associated with this export job.
final
hashCode → int
The hash code for this object.
no setterinherited
revisionId → String
The unique identifier for the revision associated with this export response.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signedUrl → String?
The signed URL for the export request.
final
signedUrlExpiresAt → DateTime?
The date and time that the signed URL expires, in ISO 8601 format.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited