ExportAssetsToS3RequestDetails class

Details of the operation to be performed by the job.

Constructors

ExportAssetsToS3RequestDetails({required List<AssetDestinationEntry> assetDestinations, required String dataSetId, required String revisionId, ExportServerSideEncryption? encryption})

Properties

assetDestinations → List<AssetDestinationEntry>
The destination for the asset.
final
dataSetId → String
The unique identifier for the data set associated with this export job.
final
encryption → ExportServerSideEncryption?
Encryption configuration for the export job.
final
hashCode → int
The hash code for this object.
no setterinherited
revisionId → String
The unique identifier for the revision associated with this export request.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited