ExportAssetsToS3ResponseDetails class

Details about the export to Amazon S3 response.

Constructors

ExportAssetsToS3ResponseDetails({required List<AssetDestinationEntry> assetDestinations, required String dataSetId, required String revisionId, ExportServerSideEncryption? encryption})
ExportAssetsToS3ResponseDetails.fromJson(Map<String, dynamic> json)
factory

Properties

assetDestinations → List<AssetDestinationEntry>
The destination in Amazon S3 where the asset is exported.
final
dataSetId → String
The unique identifier for the data set associated with this export job.
final
encryption → ExportServerSideEncryption?
Encryption configuration of the export job.
final
hashCode → int
The hash code for this object.
no setterinherited
revisionId → String
The unique identifier for the revision associated with this export response.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited