GetAssetResponse class

Constructors

GetAssetResponse({String? arn, AssetDetails? assetDetails, AssetType? assetType, DateTime? createdAt, String? dataSetId, String? id, String? name, String? revisionId, String? sourceId, DateTime? updatedAt})
GetAssetResponse.fromJson(Map<String, dynamic> json)
factory

Properties

arn → String?
The ARN for the asset.
final
assetDetails → AssetDetails?
Information about the asset, including its size.
final
assetType → AssetType?
The type of file your data is stored in. Currently, the supported asset type is S3_SNAPSHOT.
final
createdAt → DateTime?
The date and time that the asset was created, in ISO 8601 format.
final
dataSetId → String?
The unique identifier for the data set associated with this asset.
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
The unique identifier for the asset.
final
name → String?
The name of the asset When importing from Amazon S3, the S3 object key is used as the asset name. When exporting to Amazon S3, the asset name is used as default target S3 object key.
final
revisionId → String?
The unique identifier for the revision associated with this asset.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceId → String?
The asset ID of the owned asset corresponding to the entitled asset being viewed. This parameter is returned when an asset owner is viewing the entitled copy of its owned asset.
final
updatedAt → DateTime?
The date and time that the asset was last updated, in ISO 8601 format.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited