GetJobResponse class

Constructors

GetJobResponse({String? arn, DateTime? createdAt, ResponseDetails? details, List<JobError>? errors, String? id, State? state, Type? type, DateTime? updatedAt})
GetJobResponse.fromJson(Map<String, dynamic> json)
factory

Properties

arn → String?
The ARN for the job.
final
createdAt → DateTime?
The date and time that the job was created, in ISO 8601 format.
final
details → ResponseDetails?
Details about the job.
final
errors → List<JobError>?
The errors associated with jobs.
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
The unique identifier for the job.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → State?
The state of the job.
final
type → Type?
The job type.
final
updatedAt → DateTime?
The date and time that the job was last updated, in ISO 8601 format.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited