ImportAssetsFromS3RequestDetails class

Details of the operation to be performed by the job.

Constructors

ImportAssetsFromS3RequestDetails({required List<AssetSourceEntry> assetSources, required String dataSetId, required String revisionId})

Properties

assetSources → List<AssetSourceEntry>
Is a list of S3 bucket and object key pairs.
final
dataSetId → String
The unique identifier for the data set associated with this import job.
final
hashCode → int
The hash code for this object.
no setterinherited
revisionId → String
The unique identifier for the revision associated with this import request.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited