JobEntry class

AWS Data Exchange Jobs are asynchronous import or export operations used to create or copy assets. A data set owner can both import and export as they see fit. Someone with an entitlement to a data set can only export. Jobs are deleted 90 days after they are created.

Constructors

JobEntry({required String arn, required DateTime createdAt, required ResponseDetails details, required String id, required State state, required Type type, required DateTime updatedAt, List<JobError>? errors})
JobEntry.fromJson(Map<String, dynamic> json)
factory

Properties

arn → String
The ARN for the job.
final
createdAt → DateTime
The date and time that the job was created, in ISO 8601 format.
final
details → ResponseDetails
Details of the operation to be performed by the job, such as export destination details or import source details.
final
errors → List<JobError>?
Errors for jobs.
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
The unique identifier for the job.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → State
The state of the job.
final
type → Type
The job type.
final
updatedAt → DateTime
The date and time that the job was last updated, in ISO 8601 format.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited