JobError class

An error that occurred with the job request.

Constructors

JobError({required Code code, required String message, Details? details, JobErrorLimitName? limitName, double? limitValue, String? resourceId, JobErrorResourceTypes? resourceType})
JobError.fromJson(Map<String, dynamic> json)
factory

Properties

code → Code
The code for the job error.
final
details → Details?
final
hashCode → int
The hash code for this object.
no setterinherited
limitName → JobErrorLimitName?
The name of the limit that was reached.
final
limitValue → double?
The value of the exceeded limit.
final
message → String
The message related to the job error.
final
resourceId → String?
The unique identifier for the resource related to the error.
final
resourceType → JobErrorResourceTypes?
The type of resource related to the error.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited