ListRevisionAssetsResponse class

Constructors

ListRevisionAssetsResponse({List<AssetEntry>? assets, String? nextToken})
ListRevisionAssetsResponse.fromJson(Map<String, dynamic> json)
factory

Properties

assets → List<AssetEntry>?
The asset objects listed by the request.
final
hashCode → int
The hash code for this object.
no setterinherited
nextToken → String?
The token value retrieved from a previous call to access the next page of results.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited