RequestDetails class

The details for the request.

Constructors

RequestDetails({ExportAssetToSignedUrlRequestDetails? exportAssetToSignedUrl, ExportAssetsToS3RequestDetails? exportAssetsToS3, ImportAssetFromSignedUrlRequestDetails? importAssetFromSignedUrl, ImportAssetsFromS3RequestDetails? importAssetsFromS3})

Properties

exportAssetsToS3 → ExportAssetsToS3RequestDetails?
Details about the export to Amazon S3 request.
final
exportAssetToSignedUrl → ExportAssetToSignedUrlRequestDetails?
Details about the export to signed URL request.
final
hashCode → int
The hash code for this object.
no setterinherited
importAssetFromSignedUrl → ImportAssetFromSignedUrlRequestDetails?
Details about the import from signed URL request.
final
importAssetsFromS3 → ImportAssetsFromS3RequestDetails?
Details about the import from Amazon S3 request.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited