ResponseDetails class

Details for the response.

Constructors

ResponseDetails({ExportAssetToSignedUrlResponseDetails? exportAssetToSignedUrl, ExportAssetsToS3ResponseDetails? exportAssetsToS3, ImportAssetFromSignedUrlResponseDetails? importAssetFromSignedUrl, ImportAssetsFromS3ResponseDetails? importAssetsFromS3})
ResponseDetails.fromJson(Map<String, dynamic> json)
factory

Properties

exportAssetsToS3 → ExportAssetsToS3ResponseDetails?
Details for the export to Amazon S3 response.
final
exportAssetToSignedUrl → ExportAssetToSignedUrlResponseDetails?
Details for the export to signed URL response.
final
hashCode → int
The hash code for this object.
no setterinherited
importAssetFromSignedUrl → ImportAssetFromSignedUrlResponseDetails?
Details for the import from signed URL response.
final
importAssetsFromS3 → ImportAssetsFromS3ResponseDetails?
Details for the import from Amazon S3 response.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited