UpdateRevisionResponse class

Constructors

UpdateRevisionResponse({String? arn, String? comment, DateTime? createdAt, String? dataSetId, bool? finalized, String? id, String? sourceId, DateTime? updatedAt})
UpdateRevisionResponse.fromJson(Map<String, dynamic> json)
factory

Properties

arn → String?
The ARN for the revision.
final
comment → String?
An optional comment about the revision.
final
createdAt → DateTime?
The date and time that the revision was created, in ISO 8601 format.
final
dataSetId → String?
The unique identifier for the data set associated with this revision.
final
finalized → bool?
To publish a revision to a data set in a product, the revision must first be finalized. Finalizing a revision tells AWS Data Exchange that changes to the assets in the revision are complete. After it's in this read-only state, you can publish the revision to your products.
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
The unique identifier for the revision.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceId → String?
The revision ID of the owned revision corresponding to the entitled revision being viewed. This parameter is returned when a revision owner is viewing the entitled copy of its owned revision.
final
updatedAt → DateTime?
The date and time that the revision was last updated, in ISO 8601 format.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited